==> haskell-rere-0.2.0.1-103-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rere.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rere
version:              0.2.0.1
visibility:           public
id:                   rere-0.2.0.1-4oNiLVpdcg86avswZRnFnH
key:                  rere-0.2.0.1-4oNiLVpdcg86avswZRnFnH
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:
    Regular-expressions extended with fixpoints for context-free powers

description:
    By extending regular expressions with (explicit) fixed points
    we can recognize context-free grammars.

category:             Parsing
abi:                  16bf9e72f561cb937d8733a76ad83e44
exposed:              True
exposed-modules:
    RERE RERE.Absurd RERE.CFG RERE.CharClasses RERE.CharSet
    RERE.Examples RERE.Examples.JSON RERE.Gen RERE.LaTeX RERE.Ref
    RERE.ST RERE.Type RERE.Var

hidden-modules:       RERE.Tuples
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rere-0.2.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rere-0.2.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rere-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rere
hs-libraries:         HSrere-0.2.0.1-4oNiLVpdcg86avswZRnFnH
depends:
    QuickCheck-2.14.3-D49gE8yyhJR3GOudg4cIYs base-4.17.2.1
    containers-0.6.7 fin-0.3.1-CZ4T3nXiE8cGUrc0JtnSKl parsec-3.1.16.1
    transformers-0.5.6.2 vec-0.5-5rcPO5vNf8nDBzRrDzt9YO

haddock-interfaces:   /usr/share/doc/haskell-rere/html/rere.haddock
haddock-html:         /usr/share/doc/haskell-rere/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rere-0.2.0.1-107-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rere.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rere
version:              0.2.0.1
visibility:           public
id:                   rere-0.2.0.1-Dg6FWJuCHl98OEiKSwZrKo
key:                  rere-0.2.0.1-Dg6FWJuCHl98OEiKSwZrKo
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:
    Regular-expressions extended with fixpoints for context-free powers

description:
    By extending regular expressions with (explicit) fixed points
    we can recognize context-free grammars.

category:             Parsing
abi:                  58d3ecbb62d025bbab00be051753ee0f
exposed:              True
exposed-modules:
    RERE RERE.Absurd RERE.CFG RERE.CharClasses RERE.CharSet
    RERE.Examples RERE.Examples.JSON RERE.Gen RERE.LaTeX RERE.Ref
    RERE.ST RERE.Type RERE.Var

hidden-modules:       RERE.Tuples
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rere-0.2.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rere-0.2.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rere-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rere
hs-libraries:         HSrere-0.2.0.1-Dg6FWJuCHl98OEiKSwZrKo
depends:
    QuickCheck-2.14.3-3dx0gffu76dAd1sNzKx1gf base-4.17.2.1
    containers-0.6.7 fin-0.3.1-Eyf7E6hE6I81LXwbdA8Y43 parsec-3.1.16.1
    transformers-0.5.6.2 vec-0.5-Aq3o93dLVLccrHGoDPh5S

haddock-interfaces:   /usr/share/doc/haskell-rere/html/rere.haddock
haddock-html:         /usr/share/doc/haskell-rere/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
